@@ -7,6 +7,9 @@ DRBL_SCRIPT_PATH="${DRBL_SCRIPT_PATH:-/opt/drbl/}"
 
 . $DRBL_SCRIPT_PATH/sbin/drbl-conf-functions
 
+# Load the config in ocs-live.conf. This is specially for DRBL/Clonezilla live. It will overwrite some settings of /opt/drbl/conf/drbl-ocs.conf, such as $DIA...
+[ -e "/etc/ocs/ocs-live.conf" ] && . /etc/ocs/ocs-live.conf
+
 # Settings
 # try IP from 192.168."100".254
 private_IP_alias_eth_def="100"
@@ -56,12 +59,14 @@ case "$switch" in
      unfsd_pid=`pidof unfsd`
      nfsd_pid=`pidof nfsd`
      if [ -z "$dhcpd_pid" -o -z "$tftpd_pid" ] || [ -z "$unfsd_pid" -a -z "$nfsd_pid" ]; then
-       echo "$msg_delimiter_star_line"
-       echo "$msg_drbl_env_is_not_ready_now_config"
-       echo $msg_this_might_take_several_minutes
-       echo -n $msg_press_enter_to_continue
-       read
-       echo "$msg_delimiter_star_line"
+       if [ "$ocs_batch_mode" = "on" ]; then
+         echo "$msg_delimiter_star_line"
+         echo "$msg_drbl_env_is_not_ready_now_config"
+         echo $msg_this_might_take_several_minutes
+         echo -n $msg_press_enter_to_continue
+         read
+         echo "$msg_delimiter_star_line"
+       fi
        # Check if $ocsroot is a mountpoint or not, if not, we have to mount it.
        prepare_ocsroot_opt=""
        if ! mountpoint $ocsroot &>/dev/null; then
@@ -71,10 +76,6 @@ case "$switch" in
        drbl-live.sh $prepare_ocsroot_opt --skip-pause-in-the-end --no-prompt-drbl-live start
      fi
 
-     # Turn on: allow members of "DRBL-Client";
-     echo "For Clonezilla SE, it's better to make only PXE or DRBL client are allowed to lease IP address from this server... Modifying $DHCPDCONF_DIR/dhcpd.conf..."
-     perl -pi -e 's/(^[[:space:]]*)# allow members of "DRBL-Client";/$1allow members of "DRBL-Client";/g' $DHCPDCONF_DIR/dhcpd.conf
-
      echo "$msg_delimiter_star_line"
      echo "$msg_drbl_env_is_ready"
      echo "$msg_delimiter_star_line"
